@@ -14,6 +14,7 @@ from . import events
 from . import proxy_macos
 from .config import load_config
 from .backend_client import BackendAPIError, build_backend_api_from_context
+from .packaging_utils import get_mitmdump_path
 
 # added: logging & forwarding deps
 import os
@@ -309,9 +310,19 @@ async def start(req: Request) -> Dict[str, Any]:
         }
 
     # Step 1: preflight check for mitmdump
-    mitmdump_path = shutil.which("mitmdump")
-    if not mitmdump_path:
-        return {"ok": False, "error": "mitmdump not found. Please install mitmproxy (brew install mitmproxy)."}
+    try:
+        mitmdump_path = get_mitmdump_path()
+        # Check if the path exists and is executable
+        if mitmdump_path == "mitmdump":
+            # Fallback to system check
+            mitmdump_path = shutil.which("mitmdump")
+        if not mitmdump_path or not os.path.exists(mitmdump_path):
+            return {"ok": False, "error": "mitmdump not found. Please install mitmproxy (brew install mitmproxy)."}
+    except Exception:
+        # Fallback to original method
+        mitmdump_path = shutil.which("mitmdump")
+        if not mitmdump_path:
+            return {"ok": False, "error": "mitmdump not found. Please install mitmproxy (brew install mitmproxy)."}
 
     # Prepare vars
     bypass_domains = body.get("bypassDomains") or []
