@@ -24,6 +24,7 @@ from typing import Any, Dict, Optional, List
 from .config import load_config
 from .backend_client import BackendAPI, BackendAPIError, build_backend_api_from_context
 from .cert_manager import setup_certificate_environment
+from .packaging_utils import get_mitmdump_path
 
 
 def _analyze_test_result_for_remark(response_a, response_b):
@@ -205,10 +206,21 @@ def start_capture(cfg: Dict[str, Any]) -> Dict[str, Any]:
     """
     global _state, _proc
     # validate mitmdump
-    mitmdump_path = shutil.which("mitmdump")
-    if not mitmdump_path:
-        _state.lastError = "mitmdump not found. Please install mitmproxy (e.g., brew install mitmproxy)."
-        return {"ok": False, "error": _state.lastError}
+    try:
+        mitmdump_path = get_mitmdump_path()
+        # Check if the path exists and is executable
+        if mitmdump_path == "mitmdump":
+            # Fallback to system check
+            mitmdump_path = shutil.which("mitmdump")
+        if not mitmdump_path or not Path(mitmdump_path).exists():
+            _state.lastError = "mitmdump not found. Please install mitmproxy (e.g., brew install mitmproxy)."
+            return {"ok": False, "error": _state.lastError}
+    except Exception:
+        # Fallback to original method
+        mitmdump_path = shutil.which("mitmdump")
+        if not mitmdump_path:
+            _state.lastError = "mitmdump not found. Please install mitmproxy (e.g., brew install mitmproxy)."
+            return {"ok": False, "error": _state.lastError}
     # validate port
     port = _coerce_port(cfg.get("port"))
     if not port:
